@@ -3,7 +3,7 @@ use strict;
 use warnings;
 
 use 5.008_005;
-our $VERSION = 'v0.1.1';
+our $VERSION = 'v0.1.3';
 
 use File::Spec;
 use HTTP::AcceptLanguage;
@@ -151,19 +151,20 @@ Amon2::Plugin::L10N is L10N support plugin for Amon2.
       accept_langs          => [qw/ en ja zh-tw zh-cn fr /],
       before_detection_hook => sub {
           my $c = shift;
+          return unless ref($c);
   
+          my $accept_re = qr/\A(?:en|ja|zh-tw)\z/;
           my $lang = $c->req->param('lang');
-          if ($lang && $lang =~ /\A(?:en|ja|zh-tw)\z/) {
+          if ($lang && $lang =~ $accept_re) {
               $c->session->set( lang => $lang );
               return $lang;
-          } else {
-              $c->session->set( lang => '' );
-          }
-  
-          $lang = $c->session->get('lang');
-          if ($lang && $lang =~ /\A(?:en|ja|zh-tw)\z/) {
-              return $lang;
+          } elsif (! defined $lang) {
+              $lang = $c->session->get('lang');
+              if ($lang && $lang =~ $accept_re) {
+                  return $lang;
+              }
           }
+          $c->session->set( lang => '' );
           return; # through
       },
   });
@@ -226,6 +227,12 @@ Amon2::Plugin::L10N is L10N support plugin for Amon2.
 
 =head1 Translation Step
 
+=head2 installing dependent module of amon2-xgettext.pl
+
+  $ cpanm --width-suggests Amon2::Plugin::L10N
+
+dependnt module list in the L<cpanfile> file.
+
 =head2 write your application
 
 =head2 run amon2-xgettext.pl
@@ -255,6 +262,7 @@ it under the same terms as Perl itself.
 
 L<Amon2>,
 L<Locale::Maketext::Lexicon>,
-L<HTTP::AcceptLanguage>
+L<HTTP::AcceptLanguage>,
+L<amon2-xgettext.pl>
 
 =cut
